@@ -211,6 +211,7 @@ void QDiffuseSpecularMaterialPrivate::handleTextureScaleChanged(const QVariant &
 
 /*!
     \class Qt3DExtras::QDiffuseSpecularMaterial
+    \ingroup qt3d-extras-materials
     \brief The QDiffuseSpecularMaterial class provides a default implementation
     of the phong lighting effect.
     \inmodule Qt3DExtras
@@ -252,7 +253,7 @@ void QDiffuseSpecularMaterialPrivate::handleTextureScaleChanged(const QVariant &
     \list
     \li Ambient is the color that is emitted by an object without any other
         light source.
-    \li Diffuse is the color that is emitted for rought surface reflections
+    \li Diffuse is the color that is emitted for rough surface reflections
         with the lights.
     \li Specular is the color emitted for shiny surface reflections with the
         lights.
@@ -284,12 +285,14 @@ QDiffuseSpecularMaterial::~QDiffuseSpecularMaterial()
 /*!
     \property QDiffuseSpecularMaterial::ambient
 
-    Holds the ambient color.
+    Holds the ambient color that is emitted by an object without any other
+    light source.
 */
 /*!
     \qmlproperty color DiffuseSpecularMaterial::ambient
 
-    Holds the ambient color.
+    Holds the ambient color that is emitted by an object without any other
+    light source.
 */
 QColor QDiffuseSpecularMaterial::ambient() const
 {
@@ -300,14 +303,16 @@ QColor QDiffuseSpecularMaterial::ambient() const
 /*!
     \property QDiffuseSpecularMaterial::diffuse
 
-    Holds the diffuse color of the material. This can be either a plain color
-    value or a texture.
+    Holds the diffuse color of the material that is emitted for rough surface
+    reflections with the lights. This can be either a plain color value or a
+    texture.
 */
 /*!
     \qmlproperty var DiffuseSpecularMaterial::diffuse
 
-    Holds the diffuse color of the material. This can be either a plain color
-    value or a texture.
+    Holds the diffuse color of the material that is emitted for rough surface
+    reflections with the lights. This can be either a plain color value or a
+    texture.
 */
 QVariant QDiffuseSpecularMaterial::diffuse() const
 {
@@ -318,14 +323,16 @@ QVariant QDiffuseSpecularMaterial::diffuse() const
 /*!
     \property QDiffuseSpecularMaterial::specular
 
-    Holds the specular color of the material. This can be either a plain color
-    value or a texture.
+    Holds the specular color of the material that is emitted for shiny surface
+    reflections with the lights. This can be either a plain color value or a
+    texture.
 */
 /*!
     \qmlproperty var DiffuseSpecularMaterial::specular
 
-    Holds the specular color of the material. This can be either a plain color
-    value or a texture.
+    Holds the specular color of the material that is emitted for shiny surface
+    reflections with the lights. This can be either a plain color value or a
+    texture.
 */
 QVariant QDiffuseSpecularMaterial::specular() const
 {
@@ -336,12 +343,18 @@ QVariant QDiffuseSpecularMaterial::specular() const
 /*!
     \property QDiffuseSpecularMaterial::shininess
 
-    Holds the shininess exponent.
+    Holds the shininess exponent. Higher values of shininess result in
+    a smaller and brighter highlight.
+
+    Defaults to 150.0.
 */
 /*!
     \qmlproperty real DiffuseSpecularMaterial::shininess
 
-    Holds the shininess exponent.
+    Holds the shininess exponent. Higher values of shininess result in
+    a smaller and brighter highlight.
+
+    Defaults to 150.0.
 */
 float QDiffuseSpecularMaterial::shininess() const
 {
